translate.lang.es

Package translate :: Package lang :: Module es |
[hide private]
[frames] | no frames]

# Module es

source code

This module represents Spanish language. However, as it only has special case code for initial inverted punctuation, it could also be used for Asturian, Galician, or Catalan.

Classes | [hide private]
| es This class represents Spanish.

Variables | [hide private]
| __package__ = ``'``translate.lang``'``

Imports: common